@@ -421,9 +421,8 @@ class RedisRoot:
         for django_model, django_model_cache_data in self.registered_django_models.items():
             now = datetime.datetime.now()
             to_cache_in = django_model_cache_data['to_cache_in']
-            print(f'{django_model = }, {to_cache_in = }')
             cache_conf = django_model_cache_data['cache_conf']
-            if to_cache_in >= now and cache_conf['enabled']:
+            if to_cache_in <= now and cache_conf['enabled']:
                 django_models_to_cache[django_model] = cache_conf
                 ttl = cache_conf['ttl']
                 now = datetime.datetime.now()
